pub trait DirProviderBuilder<R: Runtime>: Send + Sync {
// Required method
fn build(
&self,
runtime: R,
store: DirMgrStore<R>,
circmgr: Arc<CircMgr<R>>,
config: DirMgrConfig,
) -> Result<Arc<dyn DirProvider + 'static>>;
}Expand description
An object that knows how to construct some kind of DirProvider.
Note that this type is only actually exposed when the experimental-api
feature is enabled.
Required Methods
fn build( &self, runtime: R, store: DirMgrStore<R>, circmgr: Arc<CircMgr<R>>, config: DirMgrConfig, ) -> Result<Arc<dyn DirProvider + 'static>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".