struct RunningInner<R: Runtime> {
chanmgr: Arc<ChanMgr<R>>,
circmgr: Arc<CircMgr<R>>,
dirmgr: Arc<dyn DirProvider>,
bridge_desc_mgr: Arc<Mutex<Option<Arc<BridgeDescMgr<R>>>>>,
pt_mgr: Arc<PtMgr<R>>,
hsclient: HsClientConnector<R>,
hs_circ_pool: Arc<HsCircPool<R>>,
guardmgr: GuardMgr<R>,
}Expand description
Data structures for a “running” client.
A running client is one that is either bootstrapped, or potentially trying to bootstrap.
All structures that potentially interact with the network belong here.
We defer the creation of this structure and its members until bootstrap time, to make sure that before we are bootstrapping, nothing will try to connect to the network or launch expensive background tasks.
Fields
chanmgr: Arc<ChanMgr<R>>Channel manager, used by circuits etc.,
Used directly by client only for reconfiguration.
circmgr: Arc<CircMgr<R>>Circuit manager for keeping our circuits up to date and building them on-demand.
dirmgr: Arc<dyn DirProvider>Directory manager for keeping our directory material up to date.
bridge_desc_mgr: Arc<Mutex<Option<Arc<BridgeDescMgr<R>>>>>Bridge descriptor manager
None until we have bootstrapped.
Lock hierarchy: don’t acquire this before dormant
pt_mgr: Arc<PtMgr<R>>Pluggable transport manager.
hsclient: HsClientConnector<R>HS client connector
hs_circ_pool: Arc<HsCircPool<R>>Circuit pool for providing onion services with circuits.
guardmgr: GuardMgr<R>Guard manager
Implementations
Sourceimpl<R: Runtime> RunningInner<R>
impl<R: Runtime> RunningInner<R>
Sourcefn new(
pending: NotConstructedInner<R>,
client: &ClientShared<R>,
) -> StdResult<Arc<Self>, ErrorDetail>
fn new( pending: NotConstructedInner<R>, client: &ClientShared<R>, ) -> StdResult<Arc<Self>, ErrorDetail>
Construct a new RunningInner and launch its associated tasks.
Sourcefn reconfigure(
&self,
new_config: &TorClientConfig,
how: Reconfigure,
) -> Result<()>
fn reconfigure( &self, new_config: &TorClientConfig, how: Reconfigure, ) -> Result<()>
Tell the parts of this RunningInner to reconfigure themselves
(or to check the new configuration, if how == CheckAllOrNothing).