pub struct OnionServiceConfigBuilder {
nickname: Option<HsNickname>,
enabled: Option<bool>,
num_intro_points: Option<u8>,
rate_limit_at_intro: Option<Option<TokenBucketConfig>>,
max_concurrent_streams_per_circuit: Option<u32>,
enable_pow: Option<bool>,
pow_rend_queue_depth: Option<usize>,
restricted_discovery: RestrictedDiscoveryConfigBuilder,
disable_pow_compilation: Option<bool>,
}Expand description
A builder to create an instance of OnionServiceConfig.
Fields
nickname: Option<HsNickname>enabled: Option<bool>num_intro_points: Option<u8>rate_limit_at_intro: Option<Option<TokenBucketConfig>>max_concurrent_streams_per_circuit: Option<u32>enable_pow: Option<bool>pow_rend_queue_depth: Option<usize>restricted_discovery: RestrictedDiscoveryConfigBuilderdisable_pow_compilation: Option<bool>Implementations
Sourceimpl OnionServiceConfigBuilder
impl OnionServiceConfigBuilder
Sourcepub fn nickname(&mut self, val: HsNickname) -> &mut OnionServiceConfigBuilder
pub fn nickname(&mut self, val: HsNickname) -> &mut OnionServiceConfigBuilder
Sourcepub fn enabled(&mut self, val: bool) -> &mut OnionServiceConfigBuilder
pub fn enabled(&mut self, val: bool) -> &mut OnionServiceConfigBuilder
Sourcepub fn num_intro_points(&mut self, val: u8) -> &mut OnionServiceConfigBuilder
pub fn num_intro_points(&mut self, val: u8) -> &mut OnionServiceConfigBuilder
Sourcepub fn rate_limit_at_intro(
&mut self,
val: impl PossiblyOption<TokenBucketConfig>,
) -> &mut OnionServiceConfigBuilder
pub fn rate_limit_at_intro( &mut self, val: impl PossiblyOption<TokenBucketConfig>, ) -> &mut OnionServiceConfigBuilder
Provide a value for rate_limit_at_intro.
If no value is provided for rate_limit_at_intro, build will use Default::default().
For convenience, this function accepts both TokenBucketConfig and Option<$T>
.
rate_limit_at_intro
A rate-limit on the acceptable rate of introduction requests.
We send this to the introduction point to configure how many introduction requests it sends us. If this is not set, the introduction point chooses a default based on the current consensus.
We do not enforce this limit ourselves.
This configuration is sent as a DOS_PARAMS extension, as documented in
https://spec.torproject.org/rend-spec/introduction-protocol.html#EST_INTRO_DOS_EXT.
Sourcepub fn max_concurrent_streams_per_circuit(
&mut self,
val: u32,
) -> &mut OnionServiceConfigBuilder
pub fn max_concurrent_streams_per_circuit( &mut self, val: u32, ) -> &mut OnionServiceConfigBuilder
Provide a value for max_concurrent_streams_per_circuit.
If no value is provided for max_concurrent_streams_per_circuit, build will use Default::default().
max_concurrent_streams_per_circuit
How many streams will we allow to be open at once for a single circuit on this service?
If a client attempts to open more than this many streams on a rendezvous circuit, the circuit will be torn down.
Equivalent to C Tor’s HiddenServiceMaxStreamsCloseCircuit option.
Sourcepub fn enable_pow(&mut self, val: bool) -> &mut OnionServiceConfigBuilder
pub fn enable_pow(&mut self, val: bool) -> &mut OnionServiceConfigBuilder
Sourcepub fn pow_rend_queue_depth(
&mut self,
val: usize,
) -> &mut OnionServiceConfigBuilder
pub fn pow_rend_queue_depth( &mut self, val: usize, ) -> &mut OnionServiceConfigBuilder
Provide a value for pow_rend_queue_depth.
If no value is provided for pow_rend_queue_depth, build will use Default::default().
pow_rend_queue_depth
The maximum number of entries allowed in the rendezvous request queue when PoW is enabled.
If you are seeing dropped requests, have a bursty traffic pattern, and have some memory to spare, you may want to increase this.
Each request will take a few KB, the default queue is expected to take 32MB at most.
Sourcepub fn restricted_discovery(&mut self) -> &mut RestrictedDiscoveryConfigBuilder
pub fn restricted_discovery(&mut self) -> &mut RestrictedDiscoveryConfigBuilder
Return a mutable reference to the inner builder for restricted_discovery.
restricted_discovery
Configure restricted discovery mode.
When this is enabled, we encrypt our list of introduction point and keys so that only clients holding one of the listed keys can decrypt it.
Sourcepub fn disable_pow_compilation(
&mut self,
val: bool,
) -> &mut OnionServiceConfigBuilder
pub fn disable_pow_compilation( &mut self, val: bool, ) -> &mut OnionServiceConfigBuilder
Sourceimpl OnionServiceConfigBuilder
impl OnionServiceConfigBuilder
Sourcepub fn new() -> OnionServiceConfigBuilder
pub fn new() -> OnionServiceConfigBuilder
Return a new builder object.
Sourcepub fn build(&self) -> Result<OnionServiceConfig, ConfigBuildError>
pub fn build(&self) -> Result<OnionServiceConfig, ConfigBuildError>
Try to construct a new OnionServiceConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl OnionServiceConfigBuilder
impl OnionServiceConfigBuilder
Sourcepub fn peek_nickname(&self) -> Option<&HsNickname>
pub fn peek_nickname(&self) -> Option<&HsNickname>
Return the configured nickname for this service, if it has one.