pub struct TransportConfig { /* private fields */ }Available on crate feature
pt-client only.Expand description
A single pluggable transport.
Pluggable transports are programs that transform and obfuscate traffic on the network between a Tor client and a Tor bridge, so that an adversary cannot recognize it as Tor traffic.
A pluggable transport can be either managed (run as an external process that we launch and monitor), or unmanaged (running on a local port, not controlled by Arti).
Implementations
Sourceimpl TransportConfig
impl TransportConfig
Sourcepub fn builder() -> TransportConfigBuilder
pub fn builder() -> TransportConfigBuilder
Return a new [TransportConfig Builder] to construct an instance of this type.