pub struct TransportConfigBuilder {
protocols: Option<Vec<PtTransportName>>,
path: Option<Option<CfgPath>>,
arguments: Option<Vec<String>>,
proxy_addr: Option<Option<SocketAddr>>,
run_on_startup: Option<bool>,
}Expand description
A builder to create an instance of TransportConfig.
Fields
protocols: Option<Vec<PtTransportName>>path: Option<Option<CfgPath>>arguments: Option<Vec<String>>proxy_addr: Option<Option<SocketAddr>>run_on_startup: Option<bool>Implementations
Sourceimpl TransportConfigBuilder
impl TransportConfigBuilder
Sourcepub fn protocols(
&mut self,
val: Vec<PtTransportName>,
) -> &mut TransportConfigBuilder
pub fn protocols( &mut self, val: Vec<PtTransportName>, ) -> &mut TransportConfigBuilder
Provide a value for protocols.
If no value is provided for protocols, build will fail with an error.
protocols
Names of the transport protocols that we are willing to use from this transport.
(These protocols are arbitrary identifiers that describe which protocols we want. They must match names that the binary knows how to provide.)
Sourcepub fn path(&mut self, val: CfgPath) -> &mut TransportConfigBuilder
pub fn path(&mut self, val: CfgPath) -> &mut TransportConfigBuilder
Provide a value for path.
If no value is provided for path, build will use Default::default().
For convenience, this function accepts both CfgPath and Option<$T>
.
path
The path to the binary to run, if any.
This needs to be the path to some executable file on disk.
Present only for managed transports.
Sourcepub fn arguments(&mut self, val: Vec<String>) -> &mut TransportConfigBuilder
pub fn arguments(&mut self, val: Vec<String>) -> &mut TransportConfigBuilder
Sourcepub fn proxy_addr(&mut self, val: SocketAddr) -> &mut TransportConfigBuilder
pub fn proxy_addr(&mut self, val: SocketAddr) -> &mut TransportConfigBuilder
Sourcepub fn run_on_startup(&mut self, val: bool) -> &mut TransportConfigBuilder
pub fn run_on_startup(&mut self, val: bool) -> &mut TransportConfigBuilder
Sourceimpl TransportConfigBuilder
impl TransportConfigBuilder
Sourcepub fn new() -> TransportConfigBuilder
pub fn new() -> TransportConfigBuilder
Return a new builder object.
Sourcepub fn build(&self) -> Result<TransportConfig, ConfigBuildError>
pub fn build(&self) -> Result<TransportConfig, ConfigBuildError>
Try to construct a new TransportConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl TransportConfigBuilder
impl TransportConfigBuilder
Sourcepub fn get_protocols(&self) -> &[PtTransportName]
pub fn get_protocols(&self) -> &[PtTransportName]
Inspect the list of protocols (ie, transport names)
If none have yet been specified, returns an empty list.