#[non_exhaustive]pub struct BridgesConfigBuilder {
enabled: Option<BoolOrAuto>,
bridges: BridgeListBuilder,
transports: TransportConfigListBuilder,
}Expand description
A builder to create an instance of BridgesConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<BoolOrAuto>In-progress value for enabled.
bridges: BridgeListBuilderIn-progress value for bridges.
transports: TransportConfigListBuilderIn-progress value for transports.
Implementations
Sourceimpl BridgesConfigBuilder
impl BridgesConfigBuilder
Sourcepub fn enabled(&mut self, val: BoolOrAuto) -> &mut Self
pub fn enabled(&mut self, val: BoolOrAuto) -> &mut Self
Provide a value for enabled.
If no value is provided for enabled, build will use Default::default().
enabled
Should we use configured bridges?
The default (Auto) is to use bridges if they are configured.
false means to not use even configured bridges.
true means to insist on the use of bridges;
if none are configured, that’s then an error.
Sourceimpl BridgesConfigBuilder
impl BridgesConfigBuilder
Sourcepub fn transports(
&mut self,
) -> &mut Vec<<<Vec<TransportConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>
pub fn transports( &mut self, ) -> &mut Vec<<<Vec<TransportConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_transports(
&mut self,
list: Vec<<<Vec<TransportConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>,
)
pub fn set_transports( &mut self, list: Vec<<<Vec<TransportConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>, )
Set the whole list (overriding the default)
Sourcepub fn opt_transports(
&self,
) -> &Option<Vec<<<Vec<TransportConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
pub fn opt_transports( &self, ) -> &Option<Vec<<<Vec<TransportConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_transports_mut(
&mut self,
) -> &mut Option<Vec<<<Vec<TransportConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
pub fn opt_transports_mut( &mut self, ) -> &mut Option<Vec<<<Vec<TransportConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.
Sourceimpl BridgesConfigBuilder
impl BridgesConfigBuilder
Sourcepub fn build(&self) -> Result<BridgesConfig, ConfigBuildError>
pub fn build(&self) -> Result<BridgesConfig, ConfigBuildError>
Try to construct a new BridgesConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl BridgesConfigBuilder
impl BridgesConfigBuilder
Sourcepub fn bridges(&mut self) -> &mut Vec<BridgeConfigBuilder>
pub fn bridges(&mut self) -> &mut Vec<BridgeConfigBuilder>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_bridges(&mut self, list: Vec<BridgeConfigBuilder>)
pub fn set_bridges(&mut self, list: Vec<BridgeConfigBuilder>)
Set the whole list (overriding the default)
Sourcepub fn opt_bridges(&self) -> &Option<Vec<BridgeConfigBuilder>>
pub fn opt_bridges(&self) -> &Option<Vec<BridgeConfigBuilder>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_bridges_mut(&mut self) -> &mut Option<Vec<BridgeConfigBuilder>>
pub fn opt_bridges_mut(&mut self) -> &mut Option<Vec<BridgeConfigBuilder>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.