pub type BridgeList = Vec<BridgeConfig>;Expand description
List of configured bridges, as found in the built configuration
Aliased Type
pub struct BridgeList { /* private fields */ }pub type BridgeList = Vec<BridgeConfig>;List of configured bridges, as found in the built configuration
pub struct BridgeList { /* private fields */ }