Enum arti_client::TorAddrError
source · [−]#[non_exhaustive]
pub enum TorAddrError {
InvalidHostname,
NoPort,
BadPort,
}Expand description
An error created while making or using a TorAddr.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidHostname
Tried to parse a string that can never be interpreted as a valid host.
NoPort
Tried to parse a string as an address:port, but it had no port.
BadPort
Tried to parse a port that wasn’t a valid nonzero u16.