TorAddr

Struct TorAddr 

pub struct TorAddr {
    host: Host,
    port: u16,
}
An address object that you can connect to over the Tor network.

When you’re making a connection with Tor, you shouldn’t do your DNS lookups locally: that would leak your target address to your DNS server. Instead, it’s better to use a combination of a hostname and a port directly.

The preferred way to create a TorAddr is via the IntoTorAddr trait, using a hostname and a port (or a string containing a hostname and a port). It’s also okay to use an IP and Port there, but only if they come from some source other than a local DNS lookup.

In order to discourage local hostname lookups, the functions that construct a TorAddr from IpAddr, SocketAddr, and so forth are labeled as “dangerous”.

Examples

Making a TorAddr from various “safe” sources:

use arti_client::IntoTorAddr;

let example_from_tuple = ("example.com", 80).into_tor_addr()?;
let example_from_string = "example.com:80".into_tor_addr()?;

assert_eq!(example_from_tuple, example_from_string);

Making a TorAddr from an IP address and port:

Warning: This example is only safe because we’re not doing a DNS lookup; rather, the intent is to connect to a hardcoded IP address. If you’re using DangerouslyIntoTorAddr, pay careful attention to where your IP addresses are coming from, and whether there’s a risk of information leakage.

use arti_client::DangerouslyIntoTorAddr;
use std::net::{IpAddr, SocketAddr};

let quad_one_dns: SocketAddr = "1.1.1.1:53".parse()?;
let addr_from_socketaddr = quad_one_dns.into_tor_addr_dangerously()?;

let quad_one_ip: IpAddr = "1.1.1.1".parse()?;
let addr_from_tuple = (quad_one_ip, 53).into_tor_addr_dangerously()?;

assert_eq!(addr_from_socketaddr, addr_from_tuple);

Fields

host: Host

The target host.

port: u16

The target port number.

Implementations

Source

impl TorAddr

fn new(host: Host, port: u16) -> Result<Self, TorAddrError>

Construct a TorAddr from its constituent parts, rejecting it if the port is zero.

pub fn from<A: IntoTorAddr>(addr: A) -> Result<Self, TorAddrError>

Construct a TorAddr from any object that implements IntoTorAddr.

pub fn dangerously_from<A: DangerouslyIntoTorAddr>( addr: A, ) -> Result<Self, TorAddrError>

Construct a TorAddr from any object that implements DangerouslyIntoTorAddr.

See DangerouslyIntoTorAddr for an explanation of why the style of programming supported by this function is dangerous to use.

pub fn is_ip_address(&self) -> bool

Return true if this is an IP address (rather than a hostname).

pub fn as_ip_address(&self) -> Option<&IpAddr>

If this TorAddr is an explicit IP address, return a reference to that IpAddr.

pub(crate) fn into_stream_instructions( self, cfg: &ClientAddrConfig, prefs: &StreamPrefs, ) -> Result<StreamInstructions, ErrorDetail>

Get instructions for how to make a stream to this address

pub(crate) fn into_resolve_instructions( self, cfg: &ClientAddrConfig, prefs: &StreamPrefs, ) -> Result<ResolveInstructions, ErrorDetail>

Get instructions for how to make a stream to this address

fn is_local(&self) -> bool

Return true if the host in this address is local.

fn enforce_config( &self, cfg: &ClientAddrConfig, prefs: &StreamPrefs, ) -> Result<(), ErrorDetail>

Give an error if this address doesn’t conform to the rules set in cfg.