pub struct AuthorityContacts {
v3idents: Vec<RsaIdentity>,
uploads: Vec<Vec<SocketAddr>>,
downloads: Vec<Vec<SocketAddr>>,
votes: Vec<Vec<SocketAddr>>,
}Expand description
The contact information for all directory authorities this implementation is aware of.
This data structure makes use of proposal 330 in order to distinguish authorities by their responsibilities, hence why the fields are divided.
Fields
v3idents: Vec<RsaIdentity>uploads: Vec<Vec<SocketAddr>>downloads: Vec<Vec<SocketAddr>>votes: Vec<Vec<SocketAddr>>Implementations
Sourceimpl AuthorityContacts
impl AuthorityContacts
Sourcepub fn builder() -> AuthorityContactsBuilder
pub fn builder() -> AuthorityContactsBuilder
Return a new [AuthorityContacts Builder] to construct an instance of this type.
Sourceimpl AuthorityContacts
impl AuthorityContacts
Sourcepub fn v3idents(&self) -> &Vec<RsaIdentity>
pub fn v3idents(&self) -> &Vec<RsaIdentity>
The RsaIdentity keys that may be used to sign valid consensus documents.
Sourcepub fn uploads(&self) -> &Vec<Vec<SocketAddr>>
pub fn uploads(&self) -> &Vec<Vec<SocketAddr>>
The endpoints of authorities where upload of router descriptors and other documents is possible.
This section is primarily of interest for relays.
The use of nested a Vec serves the purpose to assign multiple IPs to
a single logical authority, such as having an IPv4 and IPv6 address.
Sourcepub fn downloads(&self) -> &Vec<Vec<SocketAddr>>
pub fn downloads(&self) -> &Vec<Vec<SocketAddr>>
The endpoints of authorities where download of network documents is possible.
This section is primarily of interest for directory mirrors.
The use of nested a Vec serves the purpose to assign multiple IPs to
a single logical authority, such as having an IPv4 and IPv6 address.
Sourcepub fn votes(&self) -> &Vec<Vec<SocketAddr>>
pub fn votes(&self) -> &Vec<Vec<SocketAddr>>
The endpoints of authorities where voting for consensus documents is possible.
This section is primarily of interest for other directory authorities.
The use of nested a Vec serves the purpose to assign multiple IPs to
a single logical authority, such as having an IPv4 and IPv6 address.